==> kdissert_0.3.8.orig.tar.gz: kdissert-0.3.8/src/kdissert/shell/KDissertView.cpp <==
/***************************************************************************
 *   Copyright (C) 2004, 2005 Thomas Nagy                                  *
 *   tnagy2^8@yahoo.fr                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <qpixmap.h>
#include <qlayout.h>

#include <kiconloader.h>
#include <klocale.h>
#include <kmdichildview.h>
#include <kdebug.h>
#include <kparts/part.h>

#include "KDissertPart.h"
#include "KDissertView.h"


    KDissertView::KDissertView( QWidget *parentWidget, const char *name )
: KMdiChildView( parentWidget, name )
{
    m_part = new KDissertPart(this, "kdissertpart", parent(), 0, 0);
    part()->widget()->setFocus();

    QBoxLayout* layout = new QHBoxLayout(this, 0, -1, "kdissertviewlayout" );
    part()->widget()->reparent( this, QPoint(0, 0) );
    layout->addWidget( part()->widget() );

    setFocusProxy(part()->widget());

    connect( m_part, SIGNAL(stateChanged()), this, SLOT(updateCaption()) );
    updateCaption();
}

KDissertView::~KDissertView()
{
    delete m_part->widget();
}

KDissertPart *KDissertView::part()
{
    return m_part;
}

void KDissertView::updateCaption()
{
    QString caption = QString::null;
    if (m_part->url().isValid())
	caption = m_part->url().fileName();
    else
	caption = i18n("Untitled");

    if (m_part->isModified())
	setIcon( SmallIcon("filesave") );
    else
	setIcon( QPixmap() );

    setMDICaption( caption );
}

#include "KDissertView.moc"

==> kdissert_0.9.0.orig.tar.gz: kdissert-0.9.0/src/kdissert/shell/KDissertView.cpp <==
/***************************************************************************
 *   Copyright (C) 2004, 2005 Thomas Nagy                                  *
 *   tnagy2^8@yahoo.fr                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation (see COPYING)            *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 ***************************************************************************/

#include <qpixmap.h>
#include <qlayout.h>

#include <kiconloader.h>
#include <klocale.h>
#include <kmdichildview.h>
#include <kdebug.h>
#include <kparts/part.h>

#include "KDissertPart.h"
#include "KDissertView.h"

    KDissertView::KDissertView( QWidget *parentWidget, const char *name )
: KMdiChildView( parentWidget, name )
{
    m_part = new KDissertPart(this, "kdissertpart", parent(), 0, 0);
    part()->widget()->setFocus();

    QBoxLayout* layout = new QHBoxLayout(this, 0, -1, "kdissertviewlayout" );
    part()->widget()->reparent( this, QPoint(0, 0) );
    layout->addWidget( part()->widget() );

    setFocusProxy(part()->widget());

    connect( m_part, SIGNAL(stateChanged()), this, SLOT(updateCaption()) );
    updateCaption();
}

KDissertView::~KDissertView()
{
    delete m_part->widget();
}

KDissertPart *KDissertView::part()
{
    return m_part;
}

void KDissertView::updateCaption()
{
    QString caption = QString::null;
    if (m_part->url().isValid()) caption = m_part->url().fileName();
    else caption = i18n("Untitled");

    if (m_part->isModified()) setIcon( SmallIcon("filesave") );
    else setIcon( QPixmap() );

    setMDICaption( caption );
}

#include "KDissertView.moc"
